@@ -3,44 +3,71 @@ import json
 import click
 
 @click.command(name='run_pulls')
-@click.option('-i', '--input_file', required=True, help='Path to the input workspace file')
-@click.option('-w', '--workspace', default=None, help='Name of workspace. Auto-detect by default.')
-@click.option('-m', '--model_config', default=None, help='Name of model config. Auto-detect by default.')
-@click.option('-d', '--data', default='combData', help='Name of dataset')
-@click.option('-p', '--parameter', default='', help='Nuisance parameter(s) to run pulls on.'+\
-                                                    'Multiple parameters are separated by commas.'+\
-                                                    'Wildcards are accepted.')
-@click.option('-x', '--poi', default="", help='POIs to measure')
-@click.option('-r', '--profile', default="", help='Parameters to profile')
-@click.option('-f', '--fix', default="", help='Parameters to fix')
-@click.option('-s', '--snapshot', default="nominalNuis", help='Name of initial snapshot')
-@click.option('-o', '--outdir', default="pulls", help='Output directory')
-@click.option('-t', '--minimizer_type', default="Minuit2", help='Minimizer type')
-@click.option('-a', '--minimizer_algo', default="Migrad", help='Minimizer algorithm')
-@click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
-@click.option('--binned/--unbinned', default=True, help='Binned likelihood')
-@click.option('-q', '--precision', type=float, default=0.001, help='Precision for scan')
-@click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
-@click.option('-l', '--log_level', default="INFO", help='Log level')
-@click.option('--eigen/--no-eigen', default=False, help='Compute eigenvalues and vectors')
-@click.option('--print_level', type=int, default=1, help='Minimizer print level')
-@click.option('--strategy', type=int, default=0, help='Default strategy')
-@click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
-@click.option('--fix-multi/--no-fix-multi', default=True, help='Fix MultiPdf level 2')
-@click.option('--offset/--no-offset', default=True, help='Offset likelihood')
-@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
-@click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
-@click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
-@click.option('--batch_mode/--no-batch', default=False, help='Batch mode when evaluating likelihood')
-@click.option('--int_bin_precision', type=float, default=-1., help='Integrate the PDF over the bins '
-                                                                   'instead of using the probability '
-                                                                   'density at the bin centre')
+@click.option('-i', '--input_file', required=True, 
+              help='Path to the input workspace file')
+@click.option('-x', '--poi', required=True,
+              help='POIs to measure')
+@click.option('-o', '--outdir', default="pulls", show_default=True,
+              help='Output directory')
+@click.option('-w', '--workspace', default=None, 
+              help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', default=None, 
+              help='Name of model config. Auto-detect by default.')
+@click.option('-d', '--data', default='combData', show_default=True,
+              help='Name of dataset')
+@click.option('-p', '--parameter', default='', show_default=True,
+              help='Nuisance parameter(s) to run pulls on.'+\
+                   'Multiple parameters are separated by commas.'+\
+                   'Wildcards are accepted. All NPs are run by default.')
+@click.option('-r', '--profile', default=None, show_default=True,
+              help='Parameters to profile')
+@click.option('-f', '--fix', default=None, show_default=True,
+              help='Parameters to fix')
+@click.option('-s', '--snapshot', default="nominalNuis", show_default=True,
+              help='Name of initial snapshot')
+@click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
+              help='Minimizer type')
+@click.option('-a', '--minimizer_algo', default="Migrad", show_default=True,
+              help='Minimizer algorithm')
+@click.option('-c', '--num_cpu', type=int, default=1, show_default=True,
+              help='Number of CPUs to use per parameter')
+@click.option('--binned/--unbinned', default=True, show_default=True,
+              help='Binned likelihood')
+@click.option('-q', '--precision', type=float, default=0.001, show_default=True,
+              help='Precision for scan')
+@click.option('-e', '--eps', type=float, default=1.0, show_default=True,
+              help='Convergence criterium')
+@click.option('-l', '--log_level', default="INFO", show_default=True,
+              help='Log level')
+@click.option('--print_level', type=int, default=1, show_default=True,
+              help='Minimizer print level')
+@click.option('--strategy', type=int, default=1, show_default=True,
+              help='Default strategy')
+@click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
+              help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-multi', default=True, show_default=True,
+              help='Fix MultiPdf level 2')
+@click.option('--offset/--no-offset', default=True, show_default=True,
+              help='Offset likelihood')
+@click.option('--optimize', type=int, default=2, show_default=True,
+              help='Optimize constant terms')
+@click.option('--max_calls', type=int, default=-1, show_default=True,
+              help='Maximum number of function calls')
+@click.option('--max_iters', type=int, default=-1, show_default=True,
+              help='Maximum number of Minuit iterations')
+@click.option('--batch_mode/--no-batch', default=False, show_default=True,
+              help='Batch mode when evaluating likelihood')
+@click.option('--int_bin_precision', type=float, default=-1., show_default=True,
+              help='Integrate the PDF over the bins instead of using the probability '
+                   'density at the bin centre')
 @click.option('--parallel', type=int, default=-1, show_default=True,
               help='\b Parallelize job across the N workers.'
                    '\b Case  0: Jobs are run sequentially (for debugging).\n'
                    '\b Case -1: Jobs are run across N_CPU workers.\n')
-@click.option('--cache/--no-cache', default=True, help='Cache existing result')
-@click.option('--exclude', default="", help='Exclude NPs (wildcard is accepted)')
+@click.option('--cache/--no-cache', default=True, show_default=True,
+              help='Cache existing result')
+@click.option('--exclude', default="", show_default=True,
+              help='Exclude NPs (wildcard is accepted)')
 def run_pulls(**kwargs):
     """
     Tool for computing NP pulls and impacts
@@ -92,8 +119,17 @@ def run_pulls(**kwargs):
               help='Show energy and luminosity labels')
 @click.option('--ranking_label/--no_ranking_label', default=True, show_default=True,
               help='Show ranking label')
-@click.option('--energy', type=float, default=13, show_default=True, help='Beam energy')
-@click.option('--lumi', type=float, default=139, show_default=True, help='Luminosity')
+@click.option('--energy', default="13 TeV", show_default=True, 
+              help='Beam energy')
+@click.option('--lumi', default="139 fb$^{-1}$", show_default=True, 
+              help='Luminosity')
+@click.option('--status', default="int", show_default=True, 
+              help='\b Analysis status. Choose from'
+                   '\b            int : Internal\n'
+                   '\b            wip : Work in Progress\n'
+                   '\b         prelim : Preliminary\n'
+                   '\b          final : *no status label*\n'
+                   '\b *custom input* : *custom input*\n')
 @click.option('--combine_pdf/--split_pdf', default=True, show_default=True,
               help='Combine all ranking plots into a single pdf')
 @click.option('--outdir', default='ranking_plots', show_default=True,
