@@ -77,7 +77,7 @@ class NuisanceParameterPull(object):
 
     @staticmethod
     def _run_pulls(input_file:str, data:str, snapshot:str, nuis_name:str, poi_name:str, 
-                   fix_param:str='', profile_param:str='', binned:bool=True,
+                   fix_param:Optional[str]=None, profile_param:Optional[str]=None, binned:bool=True,
                    workspace:Optional[str]=None, model_config:Optional[str]=None,
                    minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
                    precision:float=0.001, eps:float=1.0, strategy:int=0, print_level:int=1,
@@ -103,7 +103,7 @@ class NuisanceParameterPull(object):
         model = ExtendedModel(fname=input_file, ws_name=workspace,
                               mc_name=model_config, data_name=data, 
                               snapshot_name=snapshot, binned_likelihood=binned,
-                              tag_as_measurement="pdf_", fix_cache=fix_cache, fix_multi=fix_multi)
+                              fix_cache=fix_cache, fix_multi=fix_multi)
         if fix_param:
             model.fix_parameters(fix_param)
             
@@ -271,8 +271,8 @@ class NuisanceParameterPull(object):
 
     @common_utils.timer
     def run_pulls(self, input_file:str='workspace.root', data:str='combData', poi:str='', 
-                  snapshot:str='nominalNuis', outdir:str='output', profile:str='',
-                  fix:str='', workspace:Optional[str]=None, model_config:Optional[str]=None,
+                  snapshot:str='nominalNuis', outdir:str='output', profile:Optional[str]=None,
+                  fix:Optional[str]=None, workspace:Optional[str]=None, model_config:Optional[str]=None,
                   minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', num_cpu:int=1, 
                   binned:bool=1, precision:float=0.001, eps:float=1.0, log_level:str='INFO', eigen:bool=False, 
                   strategy:int=0, print_level:int=1, fix_cache:bool=True, fix_multi:bool=True, offset:bool=True, 
