@@ -58,11 +58,13 @@ def approx_n_digit(val:float, default=5):
         return 0
 
 def str_encode_value(val, n_digit=None, formatted=True):
+    # account for the case where val is negative zero
+    if round(float(val), 8) == 0:
+        val = 0.
     if n_digit is not None:
         val_str = '{{:.{}f}}'.format(n_digit).format(val)
-        # account for the case where val is negative zero
-        if val_str == '-{{:.{}f}}'.format(n_digit).format(0):
-            val_str = '{{:.{}f}}'.format(n_digit).format(0)
+        #if val_str == '-{{:.{}f}}'.format(n_digit).format(0):
+        #    val_str = '{{:.{}f}}'.format(n_digit).format(0)
     else:
         val_str = str(val)
     
