@@ -46,10 +46,16 @@ class RooProcessor(AbstractObject):
         self.action_list = action_list
     
     def run(self, filename:str):
-        if os.path.isdir(filename):
-            all_files = glob.glob(os.path.join(filename, "*.root"))
-        else:
-            all_files = glob.glob(filename)
+        all_files = []
+        if isinstance(filename, str):
+            filename = [filename]
+        if not isinstance(filename, list):
+            raise ValueError("filename must be either string or list of strings")
+        for fname in filename:
+            if os.path.isdir(fname):
+                all_files += glob.glob(os.path.join(fname, "*.root"))
+            else:
+                all_files = glob.glob(fname)
         if not all_files:
             raise FileNotFoundError(f"file `{filename}` does not exist")
         if len(all_files) == 1:
