@@ -525,8 +525,8 @@ class NPRankingPlot:
         format_axis_ticks(ax2, y_axis=False, x_axis_styles=style['xaxis'])
         ax2.xaxis.set_ticks_position('top')
         impact_xlim = ax2.get_xlim()
-        if (abs(impact_xlim[0]) + abs(impact_xlim[1])) < 0.05:
-            ax2.xaxis.set_major_locator(plt.MaxNLocator(3))        
+        #if (abs(impact_xlim[0]) + abs(impact_xlim[1])) < 0.05:
+        #    ax2.xaxis.set_major_locator(plt.MaxNLocator(3))
         NPRankingPlot.draw_labels(ax1, extra_text=extra_text, height=height, elumi_label=elumi_label,
                                   ranking_label=ranking_label, energy=energy, lumi=lumi, status=status,
                                   r_start=r_start, r_end=r_start + n - 1, **style)
