@@ -312,8 +312,9 @@ def draw_hatches(axis, ymax, height=1.0, **styles):
     x_max    = axis.get_xlim()[1]
     x_range  = x_max - x_min
     y_values = np.arange(0, height*ymax, 2*height) - height/2
+    transform = create_transform(transform_x='axis', transform_y='data')
     for y in y_values:
-        axis.add_patch(Rectangle((x_min, y), x_range, 1, **styles, zorder=-1))
+        axis.add_patch(Rectangle((0, y), 1, 1, **styles, zorder=-1, transform=transform))
 
 def draw_text(axis, x, y, s, transform_x:str='axis', 
               transform_y:str='axis', **styles):
