@@ -1,7 +1,8 @@
-from typing import Optional, Union, Dict
+from typing import Optional, Union, Dict, List
 import os
 import sys
 import copy
+import fnmatch
 import time
 import json
 import inspect
@@ -129,6 +130,16 @@ def combine_dict(d:Dict, u:Optional[Dict]=None):
     else:
         u_copy = copy.deepcopy(u)
         return update_nested_dict(d_copy, u_copy)
+    
+def str_list_filter(source:List[str], patterns:List[str], inclusive:bool=True):
+    if inclusive:
+        result = [s for p in patterns for s in source if fnmatch.fnmatch(s, p)]
+        return sorted(list(set(result)))
+    else:
+        result = set(source)
+        for p in patterns:
+            result &= set([s for s in source if not fnmatch.fnmatch(s, p)])
+        return sorted(list(result))
 
 def get_class_that_defined_method(meth):
     if isinstance(meth, functools.partial):
